==> core-0.0.3-sources.jar: de/quantummaid/usecasemaid/sideeffects/SideEffectInstance.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.usecasemaid.sideeffects;

import de.quantummaid.reflectmaid.ResolvedType;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class SideEffectInstance<S> {
    private final S sideEffect;
    private final ResolvedType type;

    public static <S> SideEffectInstance<S> sideEffectInstance(final S sideEffect) {
        return new SideEffectInstance<>(sideEffect, ResolvedType.resolvedType(sideEffect.getClass()));
    }

    public static <S> SideEffectInstance<S> sideEffectInstance(final S sideEffect,
                                                               final ResolvedType type) {
        return new SideEffectInstance<>(sideEffect, type);
    }

    public S sideEffect() {
        return sideEffect;
    }

    public ResolvedType type() {
        return type;
    }
}

==> core-0.0.34-sources.jar: de/quantummaid/usecasemaid/sideeffects/SideEffectInstance.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.usecasemaid.sideeffects;

import de.quantummaid.reflectmaid.ReflectMaid;
import de.quantummaid.reflectmaid.resolvedtype.ResolvedType;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class SideEffectInstance<S> {
    private final S sideEffect;
    private final ResolvedType type;

    public static <S> SideEffectInstance<S> sideEffectInstance(final ReflectMaid reflectMaid,
                                                               final S sideEffect) {
        return new SideEffectInstance<>(sideEffect, reflectMaid.resolve(sideEffect.getClass()));
    }

    public static <S> SideEffectInstance<S> sideEffectInstance(final S sideEffect,
                                                               final ResolvedType type) {
        return new SideEffectInstance<>(sideEffect, type);
    }

    public S sideEffect() {
        return sideEffect;
    }

    public ResolvedType type() {
        return type;
    }
}
